#!/usr/bin/env node
"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
var fs_1 = require("fs");
var prettier_1 = __importDefault(require("prettier"));
var toTS_1 = require("./templates/model/toTS");
var toJS_1 = require("./templates/model/toJS");
var query_1 = require("./templates/query");
var mutation_1 = require("./templates/mutation");
var dist_1 = require("graphschematojson/dist");
var context_1 = require("./templates/context");
var types_1 = __importDefault(require("./templates/types"));
var _1 = require(".");
var R = __importStar(require("ramda"));
var getArgs = R.reduce(function (acc, arg) {
    var split = arg.split('=');
    if (split.length === 2) {
        return R.assoc(split[0], split[1], acc);
    }
    return acc;
}, { format: 'ts', outDir: './generated' });
var mergeConfig = function (args) {
    if (args.config) {
        return R.mergeLeft(Promise.resolve().then(function () { return __importStar(require(args.config)); }), args);
    }
    return args;
};
R.pipe(getArgs, mergeConfig, function (config) {
    if (!config.file && !config.dir) {
        throw new Error('Must provide an input file or directory for .graphql or .gql files');
    }
    var schema = '';
    if (config.file) {
        schema = fs_1.readFileSync(config.file, 'utf8');
    }
    else {
        var files = fs_1.readdirSync(config.dir);
        schema = files
            .filter(function (file) { return file.includes('.graphql') || file.includes('.gql'); })
            .map(function (file) { return fs_1.readFileSync(config.dir + "/" + file, 'utf8'); })
            .join('\n');
    }
    var jsObj = dist_1.toSchema(schema);
    var types = _1.fromSchema(jsObj);
    if (!fs_1.existsSync("" + config.outDir)) {
        fs_1.mkdirSync(config.outDir);
        fs_1.mkdirSync(config.outDir + "/models");
        fs_1.mkdirSync(config.outDir + "/schemas");
    }
    // generate model files
    if (config.format === 'ts') {
        // generate ts models
        R.mapObjIndexed(function (entity, name) {
            fs_1.writeFileSync(config.outDir + "/models/" + name + ".ts", prettier_1.default.format(toTS_1.model(entity, config.contextPath), {
                singleQuote: true,
                printWidth: 100,
                tabWidth: 4,
                parser: 'typescript',
                semi: false
            }));
        }, types);
    }
    else if (config.format === 'js') {
        // generate js models
        R.mapObjIndexed(function (entity, name) {
            fs_1.writeFileSync(config.outDir + "/models/" + name + ".js", prettier_1.default.format(toJS_1.model(entity, config.contextPath), {
                singleQuote: true,
                printWidth: 100,
                tabWidth: 4,
                semi: false
            }));
        }, types);
    }
    else {
        throw new Error('Output format has not been provided and cannot be inferred.');
    }
    //create graphQL Query file.
    var queries = query_1.toGraphQL(types);
    fs_1.writeFileSync(config.outDir + "/schemas/queries.graphql", queries);
    var mutations = mutation_1.toGraphQL(types);
    fs_1.writeFileSync(config.outDir + "/schemas/mutations.graphql", mutations);
    if (!config.contextPath) {
        fs_1.writeFileSync(config.outDir + "/context.ts", prettier_1.default.format(context_1.toTS(), {
            singleQuote: true,
            printWidth: 100,
            tabWidth: 4,
            parser: 'typescript',
            semi: false
        }));
    }
    var typeFile = types_1.default(types, config.contextPath);
    fs_1.writeFileSync(config.outDir + "/types.ts", prettier_1.default.format(typeFile, {
        singleQuote: true,
        printWidth: 100,
        tabWidth: 4,
        parser: 'typescript',
        semi: false
    }));
})(process.argv);
