import { EntitySchemaColumnOptions } from 'typeorm';
import { FieldSchema } from 'graphschematojson/dist/field';
import { ObjectSchema } from 'graphschematojson/dist/object';
import * as consts from './consts';
declare type Column = Pick<EntitySchemaColumnOptions, Exclude<keyof EntitySchemaColumnOptions, "type">> & {
    type?: string;
};
declare type PrimaryColumn = Pick<Column, Exclude<keyof Column, "primary">>;
declare type PrimaryGeneratedColumn = Pick<PrimaryColumn, Exclude<keyof PrimaryColumn, "generated">>;
export declare type ColumnField = {
    directives: {
        [consts.COLUMN]: Partial<EntitySchemaColumnOptions>;
        [key: string]: any;
    };
} & FieldSchema;
export declare type PrimaryGeneratedField = {
    directives: {
        [consts.PRIMARY_GENERATED_COLUMN]: PrimaryGeneratedColumn;
        [key: string]: any;
    };
} & FieldSchema;
export declare type PrimaryField = {
    directives: {
        [consts.PRIMARY_COLUMN]: PrimaryColumn;
        [key: string]: any;
    };
} & FieldSchema;
export declare type CreateDateField = {
    directives: {
        [consts.CREATE_DATE_COLUMN]: Pick<Column, Exclude<keyof Column, "createDate">>;
        [key: string]: any;
    };
};
export declare type UpdateDateField = {
    directives: {
        [consts.UPDATE_DATE_COLUMN]: Pick<Column, Exclude<keyof Column, "updateDate">>;
        [key: string]: any;
    };
};
export declare const isPrimary: (obj: EntitySchemaColumnOptions) => boolean;
export declare const isGenerated: (obj: EntitySchemaColumnOptions) => boolean;
export declare const isNullable: (obj: EntitySchemaColumnOptions) => boolean;
export declare const getType: (type: string) => string;
/** Get value for  whether column is nullable or not. */
export declare const getNullable: (obj: ColumnField) => boolean;
export declare const getColumn: (obj: ColumnField) => Partial<EntitySchemaColumnOptions>;
/** Convert a FieldSchema with Column Directive into TypeORM EntitySchemaColumnOptions Object */
export declare const fromColumnField: (obj: ColumnField) => {
    type: string | StringConstructor | BooleanConstructor | NumberConstructor | DateConstructor;
    nullable: true | undefined;
    primary?: boolean | undefined;
    objectId?: boolean | undefined;
    createDate?: boolean | undefined;
    updateDate?: boolean | undefined;
    version?: boolean | undefined;
    treeChildrenCount?: boolean | undefined;
    treeLevel?: boolean | undefined;
    name?: string | undefined;
    length?: string | number | undefined;
    width?: number | undefined;
    readonly?: boolean | undefined;
    update?: boolean | undefined;
    select?: boolean | undefined;
    insert?: boolean | undefined;
    generated?: true | "uuid" | "increment" | "rowid" | undefined;
    unique?: boolean | undefined;
    columnDefinition?: string | undefined;
    comment?: string | undefined;
    default?: any;
    onUpdate?: string | undefined;
    precision?: number | undefined;
    scale?: number | undefined;
    zerofill?: boolean | undefined;
    unsigned?: boolean | undefined;
    charset?: string | undefined;
    collation?: string | undefined;
    enum?: Object | any[] | undefined;
    asExpression?: string | undefined;
    generatedType?: "VIRTUAL" | "STORED" | undefined;
    hstoreType?: "string" | "object" | undefined;
    array?: boolean | undefined;
    transformer?: import("typeorm").ValueTransformer | import("typeorm").ValueTransformer[] | undefined;
    spatialFeatureType?: string | undefined;
    srid?: number | undefined;
};
/** Convert a FieldSchema with PrimaryGeneratedColumn Directive into TypeORM EntitySchemaColumnOptions Object */
export declare const fromPrimaryGeneratedField: (obj: PrimaryGeneratedField) => {
    type: string;
    primary: boolean;
    generated: boolean;
    length?: string | number | undefined;
    default?: any;
    select?: boolean | undefined;
    readonly?: boolean | undefined;
    update?: boolean | undefined;
    enum?: Object | any[] | undefined;
    array?: boolean | undefined;
    insert?: boolean | undefined;
    createDate?: boolean | undefined;
    updateDate?: boolean | undefined;
    version?: boolean | undefined;
    treeChildrenCount?: boolean | undefined;
    treeLevel?: boolean | undefined;
    objectId?: boolean | undefined;
    name?: string | undefined;
    width?: number | undefined;
    nullable?: boolean | undefined;
    unique?: boolean | undefined;
    columnDefinition?: string | undefined;
    comment?: string | undefined;
    onUpdate?: string | undefined;
    precision?: number | undefined;
    scale?: number | undefined;
    zerofill?: boolean | undefined;
    unsigned?: boolean | undefined;
    charset?: string | undefined;
    collation?: string | undefined;
    asExpression?: string | undefined;
    generatedType?: "VIRTUAL" | "STORED" | undefined;
    hstoreType?: "string" | "object" | undefined;
    transformer?: import("typeorm").ValueTransformer | import("typeorm").ValueTransformer[] | undefined;
    spatialFeatureType?: string | undefined;
    srid?: number | undefined;
};
/** Convert a FieldSchema with PrimaryColumn Directive into TypeORM EntitySchemaColumnOptions Object */
export declare const fromPrimaryField: (obj: PrimaryField) => {
    type: string;
    primary: boolean;
    length?: string | number | undefined;
    default?: any;
    select?: boolean | undefined;
    readonly?: boolean | undefined;
    update?: boolean | undefined;
    enum?: Object | any[] | undefined;
    array?: boolean | undefined;
    insert?: boolean | undefined;
    createDate?: boolean | undefined;
    updateDate?: boolean | undefined;
    version?: boolean | undefined;
    treeChildrenCount?: boolean | undefined;
    treeLevel?: boolean | undefined;
    objectId?: boolean | undefined;
    name?: string | undefined;
    width?: number | undefined;
    nullable?: boolean | undefined;
    generated?: true | "uuid" | "increment" | "rowid" | undefined;
    unique?: boolean | undefined;
    columnDefinition?: string | undefined;
    comment?: string | undefined;
    onUpdate?: string | undefined;
    precision?: number | undefined;
    scale?: number | undefined;
    zerofill?: boolean | undefined;
    unsigned?: boolean | undefined;
    charset?: string | undefined;
    collation?: string | undefined;
    asExpression?: string | undefined;
    generatedType?: "VIRTUAL" | "STORED" | undefined;
    hstoreType?: "string" | "object" | undefined;
    transformer?: import("typeorm").ValueTransformer | import("typeorm").ValueTransformer[] | undefined;
    spatialFeatureType?: string | undefined;
    srid?: number | undefined;
};
export declare const fromCreateDateField: (obj: CreateDateField) => {
    type: string;
    createDate: boolean;
    length?: string | number | undefined;
    default?: any;
    select?: boolean | undefined;
    readonly?: boolean | undefined;
    update?: boolean | undefined;
    enum?: Object | any[] | undefined;
    array?: boolean | undefined;
    insert?: boolean | undefined;
    updateDate?: boolean | undefined;
    version?: boolean | undefined;
    treeChildrenCount?: boolean | undefined;
    treeLevel?: boolean | undefined;
    objectId?: boolean | undefined;
    name?: string | undefined;
    primary?: boolean | undefined;
    width?: number | undefined;
    nullable?: boolean | undefined;
    generated?: true | "uuid" | "increment" | "rowid" | undefined;
    unique?: boolean | undefined;
    columnDefinition?: string | undefined;
    comment?: string | undefined;
    onUpdate?: string | undefined;
    precision?: number | undefined;
    scale?: number | undefined;
    zerofill?: boolean | undefined;
    unsigned?: boolean | undefined;
    charset?: string | undefined;
    collation?: string | undefined;
    asExpression?: string | undefined;
    generatedType?: "VIRTUAL" | "STORED" | undefined;
    hstoreType?: "string" | "object" | undefined;
    transformer?: import("typeorm").ValueTransformer | import("typeorm").ValueTransformer[] | undefined;
    spatialFeatureType?: string | undefined;
    srid?: number | undefined;
};
export declare const fromUpdateDateField: (obj: UpdateDateField) => {
    type: string;
    updateDate: boolean;
    length?: string | number | undefined;
    default?: any;
    select?: boolean | undefined;
    readonly?: boolean | undefined;
    update?: boolean | undefined;
    enum?: Object | any[] | undefined;
    array?: boolean | undefined;
    insert?: boolean | undefined;
    createDate?: boolean | undefined;
    version?: boolean | undefined;
    treeChildrenCount?: boolean | undefined;
    treeLevel?: boolean | undefined;
    objectId?: boolean | undefined;
    name?: string | undefined;
    primary?: boolean | undefined;
    width?: number | undefined;
    nullable?: boolean | undefined;
    generated?: true | "uuid" | "increment" | "rowid" | undefined;
    unique?: boolean | undefined;
    columnDefinition?: string | undefined;
    comment?: string | undefined;
    onUpdate?: string | undefined;
    precision?: number | undefined;
    scale?: number | undefined;
    zerofill?: boolean | undefined;
    unsigned?: boolean | undefined;
    charset?: string | undefined;
    collation?: string | undefined;
    asExpression?: string | undefined;
    generatedType?: "VIRTUAL" | "STORED" | undefined;
    hstoreType?: "string" | "object" | undefined;
    transformer?: import("typeorm").ValueTransformer | import("typeorm").ValueTransformer[] | undefined;
    spatialFeatureType?: string | undefined;
    srid?: number | undefined;
};
/** Convert a FieldSchema into a TypeORM EntitySchemaColumnOptions Object. */
export declare const fromField: (obj: FieldSchema) => EntitySchemaColumnOptions;
export declare const fromColumnsObject: (obj: any) => {
    [index: string]: EntitySchemaColumnOptions;
};
export declare const getColumns: (x0: ObjectSchema) => Record<string, FieldSchema>;
export declare const fromTypes: (x0: ObjectSchema) => {
    [index: string]: EntitySchemaColumnOptions;
};
export {};
