import { FindConditions } from 'typeorm/find-options/FindConditions';
import { FindOperator } from 'typeorm/find-options/FindOperator';
export declare type FieldType = string | number;
export interface Equals<T extends FieldType> {
    $eq: T;
}
export interface GreaterThan {
    $gt: number;
}
export interface GreaterThanOrEqual {
    $gte: number;
}
export interface In<T extends FieldType> {
    $in: T[];
}
export interface LessThan {
    $lt: number;
}
export interface LessThanOrEqual {
    $lte: number;
}
export interface NotEqual<T extends FieldType> {
    $ne: T;
}
export interface NotIn<T extends FieldType> {
    $nin: T[];
}
export declare type NumberQuery = Equals<number> | GreaterThan | GreaterThanOrEqual | LessThan | LessThanOrEqual | In<number> | NotEqual<number> | NotIn<number>;
export declare type StringQuery = Equals<string> | In<string> | NotEqual<string> | NotIn<string>;
export declare type Query<T> = {
    readonly [P in keyof T]?: T[P] | (T[P] extends number ? NumberQuery : T[P] extends string ? StringQuery : Query<T[P]>);
};
export declare type SortDirection = 'ASC' | 'DESC';
export declare type Sort<T> = {
    name: keyof T;
    id: SortDirection;
};
export declare type QueryArgs<T> = {
    where: Query<T>;
    order: Sort<T>;
    take: number;
    skip: number;
};
export declare const createWhere: <T extends {}>(query: QueryArgs<T>) => {
    [index: string]: FindOperator<T>;
};
export declare const createOrder: <T>(query: QueryArgs<T>) => Sort<T>;
export declare const createQuery: <T>(query: QueryArgs<T>) => FindConditions<T>;
